@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2014 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2018 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
@@ -13,6 +13,8 @@
 
 class RemovalPolicyWalker;
 class RemovalPurgeWalker;
+class wordlist;
+class StoreEntry;
 
 class RemovalPolicySettings
 {
@@ -35,6 +37,8 @@ public:
 
 class RemovalPolicy
 {
+    CBDATA_CLASS(RemovalPolicy);
+
 public:
     const char *_type;
     void *_data;
@@ -46,31 +50,29 @@ public:
     RemovalPolicyWalker *(*WalkInit) (RemovalPolicy * policy);
     RemovalPurgeWalker *(*PurgeInit) (RemovalPolicy * policy, int max_scan);
     void (*Stats) (RemovalPolicy * policy, StoreEntry * entry);
-private:
-    CBDATA_CLASS2(RemovalPolicy);
 };
 
 class RemovalPolicyWalker
 {
+    CBDATA_CLASS(RemovalPolicyWalker);
+
 public:
     RemovalPolicy *_policy;
     void *_data;
     const StoreEntry *(*Next) (RemovalPolicyWalker * walker);
     void (*Done) (RemovalPolicyWalker * walker);
-private:
-    CBDATA_CLASS2(RemovalPolicyWalker);
 };
 
 class RemovalPurgeWalker
 {
+    CBDATA_CLASS(RemovalPurgeWalker);
+
 public:
     RemovalPolicy *_policy;
     void *_data;
     int scanned, max_scan, locked;
     StoreEntry *(*Next) (RemovalPurgeWalker * walker);
     void (*Done) (RemovalPurgeWalker * walker);
-private:
-    CBDATA_CLASS2(RemovalPurgeWalker);
 };
 
 RemovalPolicy *createRemovalPolicy(RemovalPolicySettings * settings);
@@ -78,3 +80,4 @@ RemovalPolicy *createRemovalPolicy(RemovalPolicySettings * settings);
 typedef RemovalPolicy *REMOVALPOLICYCREATE(wordlist * args);
 
 #endif /* SQUID_REMOVALPOLICY_H */
+
